@@ -1,14 +1,5 @@
-# -*- coding: utf-8 -*-
-"""
-    nereid.ctx
-    ~~~~~~~~~
-
-    Implements the objects required to keep the context.
-
-    :copyright: (c) 2010-2012 by Openlabs Technologies & Consulting (P) Ltd.
-    :copyright: (c) 2010 by Armin Ronacher.
-    :license: GPLv3, see LICENSE for more details.
-"""
+#This file is part of Tryton & Nereid. The COPYRIGHT file at the top level of
+#this repository contains the full copyright notices and license terms.
 from flask.ctx import _RequestGlobals, RequestContext as RequestContextBase
 from flask.ctx import has_request_context
 
