@@ -1,15 +1,5 @@
-# -*- coding: utf-8 -*-
-"""
-    nereid.testing
-    ~~~~~~~~~~~~~~
-
-    Implements test support helpers.  This module is lazily imported
-    and usually not used in production environments.
-
-    :copyright: (c) 2010-2013 by Openlabs Technologies & Consulting (P) Ltd.
-    :copyright: (c) 2010 by Armin Ronacher.
-    :license: GPLv3, see LICENSE for more details.
-"""
+#This file is part of Tryton & Nereid. The COPYRIGHT file at the top level of
+#this repository contains the full copyright notices and license terms.
 from contextlib import contextmanager
 
 import jinja2
@@ -75,19 +65,12 @@ class NereidTestApp(Nereid):
                                a list of headers and an optional
                                exception context to start the response
         """
-        from trytond.transaction import Transaction
-        from trytond.pool import Pool
-
-        Website = Pool().get('nereid.website')
-        website, = Website.search([('name', '=', environ['HTTP_HOST'])])
-
         if not self.initialised:
             self.initialise()
 
-        with Transaction().set_context(company=website.company.id):
-            with self.request_context(environ):
-                response = self.full_dispatch_request()
-                return response(environ, start_response)
+        with self.request_context(environ):
+            response = self.full_dispatch_request()
+            return response(environ, start_response)
 
 
 class NereidTestCase(unittest.TestCase):
